import React, { useEffect, useState } from "react";
import { Button } from "antd";
import {
  ModalForm,
  ProTable
} from '@ant-design/pro-components';
import moment from "moment";
import { getTaOrder } from "@/services/taOrder";
import { queryTable } from '@/utils/request'

export default (props) => {
  const { open, onCancel, id } = props;

  const actionRef = React.useRef();
  const TaTaOrderList = queryTable(() => getTaOrder({ memberId: id }))

  const columns = [
    {
      title: "消费类型",
      dataIndex: "billType",
      render: (it) => it == 'consume' ? '消费' : it == 'refund' ? '退款' : it == 'recharge' ? '开卡' : it == 'withdraw' ? '提现' : '未知'
    },
    {
      title: "消费时间",
      dataIndex: "createdAt",
      render: (it) => moment(it).format("YYYY-MM-DD HH:mm:ss")
    },
  ]

  return (
    <ModalForm
      title="消费记录"
      open={open}
      modalProps={{
        destroyOnClose: true,
        onCancel: onCancel
      }}
      submitter={{
        // 完全自定义整个区域
        render: (props, doms) => {
          return [
            <Button
              onClick={onCancel}
            >
              取消
            </Button>,
            <Button
              type="primary"
              onClick={onCancel}
            >
              确定
            </Button>,
          ];
        }
      }}
    >
      <ProTable
        actionRef={actionRef}
        rowKey="cardId"
        columns={columns}
        options={false}
        search={false}
        request={TaTaOrderList}
      />
    </ModalForm>
  )
}